==> jc-1.4.0.tar.gz: scm/scmsetVarSize.h <==
// class scm.scmsetVarSize

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure
// @dep_class c246257d56c79eee scm_scmsetVarSize

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_scmsetVarSize_H_
#define _JC_scm_scmsetVarSize_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_scmsetVarSize$sub_refs	_jc_scm_scmsetVarSize$sub_refs;
typedef struct _jc_scm_scmsetVarSize$sub_nonrefs	_jc_scm_scmsetVarSize$sub_nonrefs;
typedef struct _jc_scm_scmsetVarSize$refs	_jc_scm_scmsetVarSize$refs;
typedef struct _jc_scm_scmsetVarSize$nonrefs	_jc_scm_scmsetVarSize$nonrefs;
typedef struct _jc_scm_scmsetVarSize$object	_jc_scm_scmsetVarSize$object;

typedef const struct _jc_scm_scmsetVarSize$vmethods	_jc_scm_scmsetVarSize$vmethods;
typedef const struct _jc_scm_scmsetVarSize$vtable	_jc_scm_scmsetVarSize$vtable;
typedef const struct _jc_scm_scmsetVarSize$vtype	_jc_scm_scmsetVarSize$vtype;

// Constructors
extern void _jc_scm_scmsetVarSize$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_scmsetVarSize$object *);

// Virtual methods
extern struct _jc_object *_jc_scm_scmsetVarSize$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_scmsetVarSize$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
extern struct _jc_java_lang_String$object *_jc_scm_scmsetVarSize$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_scmsetVarSize$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_scmsetVarSize$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_scmsetVarSize$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_scmsetVarSize$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_scmsetVarSize$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_scmsetVarSize$object *);
};

// Vtable
struct _jc_scm_scmsetVarSize$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_scmsetVarSize$vmethods	scm_scmsetVarSize;
};

// Vtype
struct _jc_scm_scmsetVarSize$vtype {
	_jc_type			type;
	_jc_scm_scmsetVarSize$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmsetVarSize$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmsetVarSize$refs {
    _jc_scm_scmsetVarSize$sub_refs	scm_scmsetVarSize;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmsetVarSize$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmsetVarSize$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_scmsetVarSize$sub_nonrefs	scm_scmsetVarSize;
};

// Object instance structure
struct _jc_scm_scmsetVarSize$object {
	_jc_scm_scmsetVarSize$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmsetVarSize$vtype	*vtype;
	_jc_scm_scmsetVarSize$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmsetVarSize$vtype _jc_scm_scmsetVarSize$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmsetVarSize, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmsetVarSize$class_object;

#endif	/* _JC_scm_scmsetVarSize_H_ */

==> jc-1.4.6.tar.gz: scm/scmsetVarSize.h <==
// class scm.scmsetVarSize

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure
// @dep_class c246257d56c79eee scm_scmsetVarSize

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_scmsetVarSize_H_
#define _JC_scm_scmsetVarSize_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_scmsetVarSize$sub_refs	_jc_scm_scmsetVarSize$sub_refs;
typedef struct _jc_scm_scmsetVarSize$sub_nonrefs	_jc_scm_scmsetVarSize$sub_nonrefs;
typedef struct _jc_scm_scmsetVarSize$refs	_jc_scm_scmsetVarSize$refs;
typedef struct _jc_scm_scmsetVarSize$nonrefs	_jc_scm_scmsetVarSize$nonrefs;
typedef struct _jc_scm_scmsetVarSize$object	_jc_scm_scmsetVarSize$object;

typedef const struct _jc_scm_scmsetVarSize$vmethods	_jc_scm_scmsetVarSize$vmethods;
typedef const struct _jc_scm_scmsetVarSize$vtable	_jc_scm_scmsetVarSize$vtable;
typedef const struct _jc_scm_scmsetVarSize$vtype	_jc_scm_scmsetVarSize$vtype;

// Constructors
extern void _jc_scm_scmsetVarSize$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_scmsetVarSize$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_scmsetVarSize$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_scmsetVarSize$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_scmsetVarSize$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_scmsetVarSize$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_scmsetVarSize$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_scmsetVarSize$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_scmsetVarSize$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_scmsetVarSize$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_scmsetVarSize$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_scmsetVarSize$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_scmsetVarSize$vmethods	scm_scmsetVarSize;
};

// Vtype
struct _jc_scm_scmsetVarSize$vtype {
	_jc_type			type;
	_jc_scm_scmsetVarSize$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmsetVarSize$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmsetVarSize$refs {
    _jc_scm_scmsetVarSize$sub_refs	scm_scmsetVarSize;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmsetVarSize$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmsetVarSize$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_scmsetVarSize$sub_nonrefs	scm_scmsetVarSize;
};

// Object instance structure
struct _jc_scm_scmsetVarSize$object {
	_jc_scm_scmsetVarSize$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmsetVarSize$vtype	*vtype;
	_jc_scm_scmsetVarSize$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmsetVarSize$vtype _jc_scm_scmsetVarSize$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmsetVarSize, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmsetVarSize$class_object;

#endif	/* _JC_scm_scmsetVarSize_H_ */
